@@ -1,15 +1,22 @@
 """ Model """
-from textflow.model.annotation import AnnotationSet
+from textflow.model.annotation import AnnotationSet, Annotation, AnnotationSpan
 from textflow.model.document import Document
 from textflow.model.label import Label
 from textflow.model.project import Project
 from textflow.model.user import Assignment, User
+from textflow.model.dataset import Dataset, datasets
+from textflow.model.model import models
 
 __all__ = [
+    'Annotation',
     'AnnotationSet',
+    'AnnotationSpan',
     'Document',
     'Project',
     'Label',
     'Assignment',
     'User',
+    'Dataset',
+    'datasets',
+    'models',
 ]
