@@ -7,8 +7,8 @@ view = Blueprint('about_view', __name__)
 
 @view.route('/about')
 def about():
-    """
+    """About page
 
-    :return:
+    :return: rendered about page
     """
     return render_template('about.html')
